@@ -2,10 +2,9 @@
 # -*- coding: utf-8 -*-
 
 import argparse
-import os
 import sys
-import string
 from argparse import RawTextHelpFormatter
+
 # pylint: disable=redefined-outer-name, unused-argument
 from pathlib import Path
 
@@ -16,22 +15,20 @@ from TTS.utils.synthesizer import Synthesizer
 def str2bool(v):
     if isinstance(v, bool):
         return v
-    if v.lower() in ('yes', 'true', 't', 'y', '1'):
+    if v.lower() in ("yes", "true", "t", "y", "1"):
         return True
-    if v.lower() in ('no', 'false', 'f', 'n', '0'):
+    if v.lower() in ("no", "false", "f", "n", "0"):
         return False
-    raise argparse.ArgumentTypeError('Boolean value expected.')
+    raise argparse.ArgumentTypeError("Boolean value expected.")
 
 
 def main():
-    # pylint: disable=bad-continuation
-    parser = argparse.ArgumentParser(description='''Synthesize speech on command line.\n\n'''
-
-    '''You can either use your trained model or choose a model from the provided list.\n\n'''\
-
-    '''If you don't specify any models, then it uses LJSpeech based English models\n\n'''\
-
-    '''
+    # pylint: disable=bad-option-value
+    parser = argparse.ArgumentParser(
+        description="""Synthesize speech on command line.\n\n"""
+        """You can either use your trained model or choose a model from the provided list.\n\n"""
+        """If you don't specify any models, then it uses LJSpeech based English models\n\n"""
+        """
     Example runs:
 
     # list provided models
@@ -53,106 +50,80 @@ def main():
     ./TTS/bin/synthesize.py --text "Text for TTS" --model_path path/to/config.json --config_path path/to/model.pth.tar --out_path output/path/speech.wav
         --vocoder_path path/to/vocoder.pth.tar --vocoder_config_path path/to/vocoder_config.json
 
-    ''',
-        formatter_class=RawTextHelpFormatter)
+    """,
+        formatter_class=RawTextHelpFormatter,
+    )
 
     parser.add_argument(
-        '--list_models',
+        "--list_models",
         type=str2bool,
-        nargs='?',
+        nargs="?",
         const=True,
         default=False,
-        help='list available pre-trained tts and vocoder models.'
-        )
-    parser.add_argument(
-        '--text',
-        type=str,
-        default=None,
-        help='Text to generate speech.'
-        )
+        help="list available pre-trained tts and vocoder models.",
+    )
+    parser.add_argument("--text", type=str, default=None, help="Text to generate speech.")
 
     # Args for running pre-trained TTS models.
     parser.add_argument(
-        '--model_name',
+        "--model_name",
         type=str,
-        default="tts_models/en/ljspeech/speedy-speech-wn",
-        help=
-        'Name of one of the pre-trained tts models in format <language>/<dataset>/<model_name>'
+        default="tts_models/en/ljspeech/tacotron2-DDC",
+        help="Name of one of the pre-trained tts models in format <language>/<dataset>/<model_name>",
     )
     parser.add_argument(
-        '--vocoder_name',
+        "--vocoder_name",
         type=str,
         default=None,
-        help=
-        'Name of one of the pre-trained  vocoder models in format <language>/<dataset>/<model_name>'
+        help="Name of one of the pre-trained  vocoder models in format <language>/<dataset>/<model_name>",
     )
 
     # Args for running custom models
+    parser.add_argument("--config_path", default=None, type=str, help="Path to model config file.")
     parser.add_argument(
-        '--config_path',
-        default=None,
-        type=str,
-        help='Path to model config file.'
-        )
-    parser.add_argument(
-        '--model_path',
+        "--model_path",
         type=str,
         default=None,
-        help='Path to model file.',
+        help="Path to model file.",
     )
     parser.add_argument(
-        '--out_path',
+        "--out_path",
         type=str,
-        default=Path(__file__).resolve().parent,
-        help='Path to save final wav file. Wav file will be named as the given text.',
+        default="tts_output.wav",
+        help="Output wav file path.",
     )
+    parser.add_argument("--use_cuda", type=bool, help="Run model on CUDA.", default=False)
     parser.add_argument(
-        '--use_cuda',
-        type=bool,
-        help='Run model on CUDA.',
-        default=False
-        )
-    parser.add_argument(
-        '--vocoder_path',
+        "--vocoder_path",
         type=str,
-        help=
-        'Path to vocoder model file. If it is not defined, model uses GL as vocoder. Please make sure that you installed vocoder library before (WaveRNN).',
+        help="Path to vocoder model file. If it is not defined, model uses GL as vocoder. Please make sure that you installed vocoder library before (WaveRNN).",
         default=None,
     )
-    parser.add_argument(
-        '--vocoder_config_path',
-        type=str,
-        help='Path to vocoder model config file.',
-        default=None)
+    parser.add_argument("--vocoder_config_path", type=str, help="Path to vocoder model config file.", default=None)
 
     # args for multi-speaker synthesis
+    parser.add_argument("--speakers_json", type=str, help="JSON file for multi-speaker model.", default=None)
     parser.add_argument(
-        '--speakers_json',
-        type=str,
-        help="JSON file for multi-speaker model.",
-        default=None)
-    parser.add_argument(
-        '--speaker_idx',
+        "--speaker_idx",
         type=str,
         help="if the tts model is trained with x-vectors, then speaker_idx is a file present in speakers.json else speaker_idx is the speaker id corresponding to a speaker in the speaker embedding layer.",
-        default=None)
-    parser.add_argument(
-        '--gst_style',
-        help="Wav path file for GST stylereference.",
-        default=None)
+        default=None,
+    )
+    parser.add_argument("--gst_style", help="Wav path file for GST stylereference.", default=None)
 
     # aux args
     parser.add_argument(
-        '--save_spectogram',
+        "--save_spectogram",
         type=bool,
         help="If true save raw spectogram for further (vocoder) processing in out_path.",
-        default=False)
+        default=False,
+    )
 
     args = parser.parse_args()
 
     # print the description if either text or list_models is not set
     if args.text is None and not args.list_models:
-        parser.parse_args(['-h'])
+        parser.parse_args(["-h"])
 
     # load model manager
     path = Path(__file__).parent / "../.models.json"
@@ -171,7 +142,7 @@ def main():
     # CASE2: load pre-trained models
     if args.model_name is not None:
         model_path, config_path, model_item = manager.download_model(args.model_name)
-        args.vocoder_name = model_item['default_vocoder'] if args.vocoder_name is None else args.vocoder_name
+        args.vocoder_name = model_item["default_vocoder"] if args.vocoder_name is None else args.vocoder_name
 
     if args.vocoder_name is not None:
         vocoder_path, vocoder_config_path, _ = manager.download_model(args.vocoder_name)
@@ -218,12 +189,8 @@ def main():
     wav = synthesizer.tts(args.text)
 
     # save the results
-    file_name = args.text.replace(" ", "_")[0:20]
-    file_name = file_name.translate(
-        str.maketrans('', '', string.punctuation.replace('_', ''))) + '.wav'
-    out_path = os.path.join(args.out_path, file_name)
-    print(" > Saving output to {}".format(out_path))
-    synthesizer.save_wav(wav, out_path,)
+    print(" > Saving output to {}".format(args.out_path))
+    synthesizer.save_wav(wav, args.out_path)
 
 
 if __name__ == "__main__":
