@@ -10,7 +10,7 @@ from random import randrange
 import numpy as np
 import torch
 from torch.utils.data import DataLoader
-from TTS.utils.arguments import parse_arguments, process_args
+
 from TTS.tts.datasets.preprocess import load_meta_data
 from TTS.tts.datasets.TTSDataset import MyDataset
 from TTS.tts.layers.losses import TacotronLoss
@@ -21,15 +21,19 @@ from TTS.tts.utils.speakers import parse_speakers
 from TTS.tts.utils.synthesis import synthesis
 from TTS.tts.utils.text.symbols import make_symbols, phonemes, symbols
 from TTS.tts.utils.visual import plot_alignment, plot_spectrogram
+from TTS.utils.arguments import parse_arguments, process_args
 from TTS.utils.audio import AudioProcessor
-from TTS.utils.distribute import (DistributedSampler, apply_gradient_allreduce,
-                                  init_distributed, reduce_tensor)
-from TTS.utils.generic_utils import (KeepAverage, count_parameters,
-                                     remove_experiment_folder, set_init_dict)
+from TTS.utils.distribute import DistributedSampler, apply_gradient_allreduce, init_distributed, reduce_tensor
+from TTS.utils.generic_utils import KeepAverage, count_parameters, remove_experiment_folder, set_init_dict
 from TTS.utils.radam import RAdam
-from TTS.utils.training import (NoamLR, adam_weight_decay, check_update,
-                                gradual_training_scheduler, set_weight_decay,
-                                setup_torch_training_env)
+from TTS.utils.training import (
+    NoamLR,
+    adam_weight_decay,
+    check_update,
+    gradual_training_scheduler,
+    set_weight_decay,
+    setup_torch_training_env,
+)
 
 use_cuda, num_gpus = setup_torch_training_env(True, False)
 
@@ -42,13 +46,12 @@ def setup_loader(ap, r, is_val=False, verbose=False, dataset=None):
             dataset = MyDataset(
                 r,
                 c.text_cleaner,
-                compute_linear_spec=c.model.lower() == 'tacotron',
+                compute_linear_spec=c.model.lower() == "tacotron",
                 meta_data=meta_data_eval if is_val else meta_data_train,
                 ap=ap,
-                tp=c.characters if 'characters' in c.keys() else None,
-                add_blank=c['add_blank'] if 'add_blank' in c.keys() else False,
-                batch_group_size=0 if is_val else c.batch_group_size *
-                c.batch_size,
+                tp=c.characters if "characters" in c.keys() else None,
+                add_blank=c["add_blank"] if "add_blank" in c.keys() else False,
+                batch_group_size=0 if is_val else c.batch_group_size * c.batch_size,
                 min_seq_len=c.min_seq_len,
                 max_seq_len=c.max_seq_len,
                 phoneme_cache_path=c.phoneme_cache_path,
@@ -56,11 +59,10 @@ def setup_loader(ap, r, is_val=False, verbose=False, dataset=None):
                 phoneme_language=c.phoneme_language,
                 enable_eos_bos=c.enable_eos_bos_chars,
                 verbose=verbose,
-                speaker_mapping=(speaker_mapping if (
-                    c.use_speaker_embedding
-                    and c.use_external_speaker_embedding_file
-                    ) else None)
-                )
+                speaker_mapping=(
+                    speaker_mapping if (c.use_speaker_embedding and c.use_external_speaker_embedding_file) else None
+                ),
+            )
 
             if c.use_phonemes and c.compute_input_seq_cache:
                 # precompute phonemes to have a better estimate of sequence lengths.
@@ -75,17 +77,18 @@ def setup_loader(ap, r, is_val=False, verbose=False, dataset=None):
             collate_fn=dataset.collate_fn,
             drop_last=False,
             sampler=sampler,
-            num_workers=c.num_val_loader_workers
-            if is_val else c.num_loader_workers,
-            pin_memory=False)
+            num_workers=c.num_val_loader_workers if is_val else c.num_loader_workers,
+            pin_memory=False,
+        )
     return loader
 
+
 def format_data(data):
     # setup input data
     text_input = data[0]
     text_lengths = data[1]
     speaker_names = data[2]
-    linear_input = data[3] if c.model in ["Tacotron"] else None
+    linear_input = data[3] if c.model.lower() in ["tacotron"] else None
     mel_input = data[4]
     mel_lengths = data[5]
     stop_targets = data[6]
@@ -97,21 +100,16 @@ def format_data(data):
             speaker_embeddings = data[8]
             speaker_ids = None
         else:
-            speaker_ids = [
-                speaker_mapping[speaker_name] for speaker_name in speaker_names
-            ]
+            speaker_ids = [speaker_mapping[speaker_name] for speaker_name in speaker_names]
             speaker_ids = torch.LongTensor(speaker_ids)
             speaker_embeddings = None
     else:
         speaker_embeddings = None
         speaker_ids = None
 
-
     # set stop targets view, we predict a single stop token per iteration.
-    stop_targets = stop_targets.view(text_input.shape[0],
-                                     stop_targets.size(1) // c.r, -1)
-    stop_targets = (stop_targets.sum(2) >
-                    0.0).unsqueeze(2).float().squeeze(2)
+    stop_targets = stop_targets.view(text_input.shape[0], stop_targets.size(1) // c.r, -1)
+    stop_targets = (stop_targets.sum(2) > 0.0).unsqueeze(2).float().squeeze(2)
 
     # dispatch data to GPU
     if use_cuda:
@@ -126,17 +124,26 @@ def format_data(data):
         if speaker_embeddings is not None:
             speaker_embeddings = speaker_embeddings.cuda(non_blocking=True)
 
-    return text_input, text_lengths, mel_input, mel_lengths, linear_input, stop_targets, speaker_ids, speaker_embeddings, max_text_length, max_spec_length
+    return (
+        text_input,
+        text_lengths,
+        mel_input,
+        mel_lengths,
+        linear_input,
+        stop_targets,
+        speaker_ids,
+        speaker_embeddings,
+        max_text_length,
+        max_spec_length,
+    )
 
 
-def train(data_loader, model, criterion, optimizer, optimizer_st, scheduler,
-          ap, global_step, epoch, scaler, scaler_st):
+def train(data_loader, model, criterion, optimizer, optimizer_st, scheduler, ap, global_step, epoch, scaler, scaler_st):
     model.train()
     epoch_time = 0
     keep_avg = KeepAverage()
     if use_cuda:
-        batch_n_iter = int(
-            len(data_loader.dataset) / (c.batch_size * num_gpus))
+        batch_n_iter = int(len(data_loader.dataset) / (c.batch_size * num_gpus))
     else:
         batch_n_iter = int(len(data_loader.dataset) / c.batch_size)
     end_time = time.time()
@@ -145,7 +152,18 @@ def train(data_loader, model, criterion, optimizer, optimizer_st, scheduler,
         start_time = time.time()
 
         # format data
-        text_input, text_lengths, mel_input, mel_lengths, linear_input, stop_targets, speaker_ids, speaker_embeddings, max_text_length, max_spec_length = format_data(data)
+        (
+            text_input,
+            text_lengths,
+            mel_input,
+            mel_lengths,
+            linear_input,
+            stop_targets,
+            speaker_ids,
+            speaker_embeddings,
+            max_text_length,
+            max_spec_length,
+        ) = format_data(data)
         loader_time = time.time() - end_time
 
         global_step += 1
@@ -161,35 +179,65 @@ def train(data_loader, model, criterion, optimizer, optimizer_st, scheduler,
         with torch.cuda.amp.autocast(enabled=c.mixed_precision):
             # forward pass model
             if c.bidirectional_decoder or c.double_decoder_consistency:
-                decoder_output, postnet_output, alignments, stop_tokens, decoder_backward_output, alignments_backward = model(
-                    text_input, text_lengths, mel_input, mel_lengths, speaker_ids=speaker_ids, speaker_embeddings=speaker_embeddings)
+                (
+                    decoder_output,
+                    postnet_output,
+                    alignments,
+                    stop_tokens,
+                    decoder_backward_output,
+                    alignments_backward,
+                ) = model(
+                    text_input,
+                    text_lengths,
+                    mel_input,
+                    mel_lengths,
+                    speaker_ids=speaker_ids,
+                    speaker_embeddings=speaker_embeddings,
+                )
             else:
                 decoder_output, postnet_output, alignments, stop_tokens = model(
-                    text_input, text_lengths, mel_input, mel_lengths, speaker_ids=speaker_ids, speaker_embeddings=speaker_embeddings)
+                    text_input,
+                    text_lengths,
+                    mel_input,
+                    mel_lengths,
+                    speaker_ids=speaker_ids,
+                    speaker_embeddings=speaker_embeddings,
+                )
                 decoder_backward_output = None
                 alignments_backward = None
 
             # set the [alignment] lengths wrt reduction factor for guided attention
             if mel_lengths.max() % model.decoder.r != 0:
-                alignment_lengths = (mel_lengths + (model.decoder.r - (mel_lengths.max() % model.decoder.r))) // model.decoder.r
+                alignment_lengths = (
+                    mel_lengths + (model.decoder.r - (mel_lengths.max() % model.decoder.r))
+                ) // model.decoder.r
             else:
-                alignment_lengths = mel_lengths //  model.decoder.r
+                alignment_lengths = mel_lengths // model.decoder.r
 
             # compute loss
-            loss_dict = criterion(postnet_output, decoder_output, mel_input,
-                                  linear_input, stop_tokens, stop_targets,
-                                  mel_lengths, decoder_backward_output,
-                                  alignments, alignment_lengths,
-                                  alignments_backward, text_lengths)
+            loss_dict = criterion(
+                postnet_output,
+                decoder_output,
+                mel_input,
+                linear_input,
+                stop_tokens,
+                stop_targets,
+                mel_lengths,
+                decoder_backward_output,
+                alignments,
+                alignment_lengths,
+                alignments_backward,
+                text_lengths,
+            )
 
         # check nan loss
-        if torch.isnan(loss_dict['loss']).any():
-            raise RuntimeError(f'Detected NaN loss at step {global_step}.')
+        if torch.isnan(loss_dict["loss"]).any():
+            raise RuntimeError(f"Detected NaN loss at step {global_step}.")
 
         # optimizer step
         if c.mixed_precision:
             # model optimizer step in mixed precision mode
-            scaler.scale(loss_dict['loss']).backward()
+            scaler.scale(loss_dict["loss"]).backward()
             scaler.unscale_(optimizer)
             optimizer, current_lr = adam_weight_decay(optimizer)
             grad_norm, _ = check_update(model, c.grad_clip, ignore_stopnet=True)
@@ -198,7 +246,7 @@ def train(data_loader, model, criterion, optimizer, optimizer_st, scheduler,
 
             # stopnet optimizer step
             if c.separate_stopnet:
-                scaler_st.scale(loss_dict['stopnet_loss']).backward()
+                scaler_st.scale(loss_dict["stopnet_loss"]).backward()
                 scaler.unscale_(optimizer_st)
                 optimizer_st, _ = adam_weight_decay(optimizer_st)
                 grad_norm_st, _ = check_update(model.decoder.stopnet, 1.0)
@@ -208,14 +256,14 @@ def train(data_loader, model, criterion, optimizer, optimizer_st, scheduler,
                 grad_norm_st = 0
         else:
             # main model optimizer step
-            loss_dict['loss'].backward()
+            loss_dict["loss"].backward()
             optimizer, current_lr = adam_weight_decay(optimizer)
             grad_norm, _ = check_update(model, c.grad_clip, ignore_stopnet=True)
             optimizer.step()
 
             # stopnet optimizer step
             if c.separate_stopnet:
-                loss_dict['stopnet_loss'].backward()
+                loss_dict["stopnet_loss"].backward()
                 optimizer_st, _ = adam_weight_decay(optimizer_st)
                 grad_norm_st, _ = check_update(model.decoder.stopnet, 1.0)
                 optimizer_st.step()
@@ -224,17 +272,19 @@ def train(data_loader, model, criterion, optimizer, optimizer_st, scheduler,
 
         # compute alignment error (the lower the better )
         align_error = 1 - alignment_diagonal_score(alignments)
-        loss_dict['align_error'] = align_error
+        loss_dict["align_error"] = align_error
 
         step_time = time.time() - start_time
         epoch_time += step_time
 
         # aggregate losses from processes
         if num_gpus > 1:
-            loss_dict['postnet_loss'] = reduce_tensor(loss_dict['postnet_loss'].data, num_gpus)
-            loss_dict['decoder_loss'] = reduce_tensor(loss_dict['decoder_loss'].data, num_gpus)
-            loss_dict['loss'] = reduce_tensor(loss_dict['loss'] .data, num_gpus)
-            loss_dict['stopnet_loss'] = reduce_tensor(loss_dict['stopnet_loss'].data, num_gpus) if c.stopnet else loss_dict['stopnet_loss']
+            loss_dict["postnet_loss"] = reduce_tensor(loss_dict["postnet_loss"].data, num_gpus)
+            loss_dict["decoder_loss"] = reduce_tensor(loss_dict["decoder_loss"].data, num_gpus)
+            loss_dict["loss"] = reduce_tensor(loss_dict["loss"].data, num_gpus)
+            loss_dict["stopnet_loss"] = (
+                reduce_tensor(loss_dict["stopnet_loss"].data, num_gpus) if c.stopnet else loss_dict["stopnet_loss"]
+            )
 
         # detach loss values
         loss_dict_new = dict()
@@ -248,9 +298,9 @@ def train(data_loader, model, criterion, optimizer, optimizer_st, scheduler,
         # update avg stats
         update_train_values = dict()
         for key, value in loss_dict.items():
-            update_train_values['avg_' + key] = value
-        update_train_values['avg_loader_time'] = loader_time
-        update_train_values['avg_step_time'] = step_time
+            update_train_values["avg_" + key] = value
+        update_train_values["avg_loader_time"] = loader_time
+        update_train_values["avg_step_time"] = step_time
         keep_avg.update_values(update_train_values)
 
         # print training progress
@@ -262,8 +312,7 @@ def train(data_loader, model, criterion, optimizer, optimizer_st, scheduler,
                 "loader_time": [loader_time, 2],
                 "current_lr": current_lr,
             }
-            c_logger.print_train_step(batch_n_iter, num_iter, global_step,
-                                      log_dict, loss_dict, keep_avg.avg_values)
+            c_logger.print_train_step(batch_n_iter, num_iter, global_step, log_dict, loss_dict, keep_avg.avg_values)
 
         if args.rank == 0:
             # Plot Training Iter Stats
@@ -273,7 +322,7 @@ def train(data_loader, model, criterion, optimizer, optimizer_st, scheduler,
                     "lr": current_lr,
                     "grad_norm": grad_norm,
                     "grad_norm_st": grad_norm_st,
-                    "step_time": step_time
+                    "step_time": step_time,
                 }
                 iter_stats.update(loss_dict)
                 tb_logger.tb_train_iter_stats(global_step, iter_stats)
@@ -281,17 +330,26 @@ def train(data_loader, model, criterion, optimizer, optimizer_st, scheduler,
             if global_step % c.save_step == 0:
                 if c.checkpoint:
                     # save model
-                    save_checkpoint(model, optimizer, global_step, epoch, model.decoder.r, OUT_PATH,
-                                    optimizer_st=optimizer_st,
-                                    model_loss=loss_dict['postnet_loss'],
-                                    characters=model_characters,
-                                    scaler=scaler.state_dict() if c.mixed_precision else None)
+                    save_checkpoint(
+                        model,
+                        optimizer,
+                        global_step,
+                        epoch,
+                        model.decoder.r,
+                        OUT_PATH,
+                        optimizer_st=optimizer_st,
+                        model_loss=loss_dict["postnet_loss"],
+                        characters=model_characters,
+                        scaler=scaler.state_dict() if c.mixed_precision else None,
+                    )
 
                 # Diagnostic visualizations
                 const_spec = postnet_output[0].data.cpu().numpy()
-                gt_spec = linear_input[0].data.cpu().numpy() if c.model in [
-                    "Tacotron", "TacotronGST"
-                ] else mel_input[0].data.cpu().numpy()
+                gt_spec = (
+                    linear_input[0].data.cpu().numpy()
+                    if c.model in ["Tacotron", "TacotronGST"]
+                    else mel_input[0].data.cpu().numpy()
+                )
                 align_img = alignments[0].data.cpu().numpy()
 
                 figures = {
@@ -301,7 +359,9 @@ def train(data_loader, model, criterion, optimizer, optimizer_st, scheduler,
                 }
 
                 if c.bidirectional_decoder or c.double_decoder_consistency:
-                    figures["alignment_backward"] = plot_alignment(alignments_backward[0].data.cpu().numpy(), output_fig=False)
+                    figures["alignment_backward"] = plot_alignment(
+                        alignments_backward[0].data.cpu().numpy(), output_fig=False
+                    )
 
                 tb_logger.tb_train_figures(global_step, figures)
 
@@ -310,9 +370,7 @@ def train(data_loader, model, criterion, optimizer, optimizer_st, scheduler,
                     train_audio = ap.inv_spectrogram(const_spec.T)
                 else:
                     train_audio = ap.inv_melspectrogram(const_spec.T)
-                tb_logger.tb_train_audios(global_step,
-                                          {'TrainAudio': train_audio},
-                                          c.audio["sample_rate"])
+                tb_logger.tb_train_audios(global_step, {"TrainAudio": train_audio}, c.audio["sample_rate"])
         end_time = time.time()
 
     # print epoch stats
@@ -339,31 +397,62 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
             start_time = time.time()
 
             # format data
-            text_input, text_lengths, mel_input, mel_lengths, linear_input, stop_targets, speaker_ids, speaker_embeddings, _, _ = format_data(data)
+            (
+                text_input,
+                text_lengths,
+                mel_input,
+                mel_lengths,
+                linear_input,
+                stop_targets,
+                speaker_ids,
+                speaker_embeddings,
+                _,
+                _,
+            ) = format_data(data)
             assert mel_input.shape[1] % model.decoder.r == 0
 
             # forward pass model
             if c.bidirectional_decoder or c.double_decoder_consistency:
-                decoder_output, postnet_output, alignments, stop_tokens, decoder_backward_output, alignments_backward = model(
-                    text_input, text_lengths, mel_input, speaker_ids=speaker_ids, speaker_embeddings=speaker_embeddings)
+                (
+                    decoder_output,
+                    postnet_output,
+                    alignments,
+                    stop_tokens,
+                    decoder_backward_output,
+                    alignments_backward,
+                ) = model(
+                    text_input, text_lengths, mel_input, speaker_ids=speaker_ids, speaker_embeddings=speaker_embeddings
+                )
             else:
                 decoder_output, postnet_output, alignments, stop_tokens = model(
-                    text_input, text_lengths, mel_input, speaker_ids=speaker_ids, speaker_embeddings=speaker_embeddings)
+                    text_input, text_lengths, mel_input, speaker_ids=speaker_ids, speaker_embeddings=speaker_embeddings
+                )
                 decoder_backward_output = None
                 alignments_backward = None
 
             # set the alignment lengths wrt reduction factor for guided attention
             if mel_lengths.max() % model.decoder.r != 0:
-                alignment_lengths = (mel_lengths + (model.decoder.r - (mel_lengths.max() % model.decoder.r))) // model.decoder.r
+                alignment_lengths = (
+                    mel_lengths + (model.decoder.r - (mel_lengths.max() % model.decoder.r))
+                ) // model.decoder.r
             else:
-                alignment_lengths = mel_lengths //  model.decoder.r
+                alignment_lengths = mel_lengths // model.decoder.r
 
             # compute loss
-            loss_dict = criterion(postnet_output, decoder_output, mel_input,
-                                  linear_input, stop_tokens, stop_targets,
-                                  mel_lengths, decoder_backward_output,
-                                  alignments, alignment_lengths, alignments_backward,
-                                  text_lengths)
+            loss_dict = criterion(
+                postnet_output,
+                decoder_output,
+                mel_input,
+                linear_input,
+                stop_tokens,
+                stop_targets,
+                mel_lengths,
+                decoder_backward_output,
+                alignments,
+                alignment_lengths,
+                alignments_backward,
+                text_lengths,
+            )
 
             # step time
             step_time = time.time() - start_time
@@ -371,14 +460,14 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
 
             # compute alignment score
             align_error = 1 - alignment_diagonal_score(alignments)
-            loss_dict['align_error'] = align_error
+            loss_dict["align_error"] = align_error
 
             # aggregate losses from processes
             if num_gpus > 1:
-                loss_dict['postnet_loss'] = reduce_tensor(loss_dict['postnet_loss'].data, num_gpus)
-                loss_dict['decoder_loss'] = reduce_tensor(loss_dict['decoder_loss'].data, num_gpus)
+                loss_dict["postnet_loss"] = reduce_tensor(loss_dict["postnet_loss"].data, num_gpus)
+                loss_dict["decoder_loss"] = reduce_tensor(loss_dict["decoder_loss"].data, num_gpus)
                 if c.stopnet:
-                    loss_dict['stopnet_loss'] = reduce_tensor(loss_dict['stopnet_loss'].data, num_gpus)
+                    loss_dict["stopnet_loss"] = reduce_tensor(loss_dict["stopnet_loss"].data, num_gpus)
 
             # detach loss values
             loss_dict_new = dict()
@@ -392,7 +481,7 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
             # update avg stats
             update_train_values = dict()
             for key, value in loss_dict.items():
-                update_train_values['avg_' + key] = value
+                update_train_values["avg_" + key] = value
             keep_avg.update_values(update_train_values)
 
             if c.print_eval:
@@ -402,15 +491,17 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
             # Diagnostic visualizations
             idx = np.random.randint(mel_input.shape[0])
             const_spec = postnet_output[idx].data.cpu().numpy()
-            gt_spec = linear_input[idx].data.cpu().numpy() if c.model in [
-                "Tacotron", "TacotronGST"
-            ] else mel_input[idx].data.cpu().numpy()
+            gt_spec = (
+                linear_input[idx].data.cpu().numpy()
+                if c.model in ["Tacotron", "TacotronGST"]
+                else mel_input[idx].data.cpu().numpy()
+            )
             align_img = alignments[idx].data.cpu().numpy()
 
             eval_figures = {
                 "prediction": plot_spectrogram(const_spec, ap, output_fig=False),
                 "ground_truth": plot_spectrogram(gt_spec, ap, output_fig=False),
-                "alignment": plot_alignment(align_img, output_fig=False)
+                "alignment": plot_alignment(align_img, output_fig=False),
             }
 
             # Sample audio
@@ -418,14 +509,13 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
                 eval_audio = ap.inv_spectrogram(const_spec.T)
             else:
                 eval_audio = ap.inv_melspectrogram(const_spec.T)
-            tb_logger.tb_eval_audios(global_step, {"ValAudio": eval_audio},
-                                     c.audio["sample_rate"])
+            tb_logger.tb_eval_audios(global_step, {"ValAudio": eval_audio}, c.audio["sample_rate"])
 
             # Plot Validation Stats
 
             if c.bidirectional_decoder or c.double_decoder_consistency:
                 align_b_img = alignments_backward[idx].data.cpu().numpy()
-                eval_figures['alignment2'] = plot_alignment(align_b_img, output_fig=False)
+                eval_figures["alignment2"] = plot_alignment(align_b_img, output_fig=False)
             tb_logger.tb_eval_stats(global_step, keep_avg.avg_values)
             tb_logger.tb_eval_figures(global_step, eval_figures)
 
@@ -436,7 +526,7 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
                 "Be a voice, not an echo.",
                 "I'm sorry Dave. I'm afraid I can't do that.",
                 "This cake is great. It's so delicious and moist.",
-                "Prior to November 22, 1963."
+                "Prior to November 22, 1963.",
             ]
         else:
             with open(c.test_sentences_file, "r") as f:
@@ -447,13 +537,17 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
         test_figures = {}
         print(" | > Synthesizing test sentences")
         speaker_id = 0 if c.use_speaker_embedding else None
-        speaker_embedding = speaker_mapping[list(speaker_mapping.keys())[randrange(len(speaker_mapping)-1)]]['embedding'] if c.use_external_speaker_embedding_file and c.use_speaker_embedding else None
+        speaker_embedding = (
+            speaker_mapping[list(speaker_mapping.keys())[randrange(len(speaker_mapping) - 1)]]["embedding"]
+            if c.use_external_speaker_embedding_file and c.use_speaker_embedding
+            else None
+        )
         style_wav = c.get("gst_style_input")
         if style_wav is None and c.use_gst:
             # inicialize GST with zero dict.
             style_wav = {}
             print("WARNING: You don't provided a gst style wav, for this reason we use a zero tensor!")
-            for i in range(c.gst['gst_style_tokens']):
+            for i in range(c.gst["gst_style_tokens"]):
                 style_wav[str(i)] = 0
         style_wav = c.get("gst_style_input")
         for idx, test_sentence in enumerate(test_sentences):
@@ -468,25 +562,22 @@ def evaluate(data_loader, model, criterion, ap, global_step, epoch):
                     speaker_embedding=speaker_embedding,
                     style_wav=style_wav,
                     truncated=False,
-                    enable_eos_bos_chars=c.enable_eos_bos_chars, #pylint: disable=unused-argument
+                    enable_eos_bos_chars=c.enable_eos_bos_chars,  # pylint: disable=unused-argument
                     use_griffin_lim=True,
-                    do_trim_silence=False)
+                    do_trim_silence=False,
+                )
 
                 file_path = os.path.join(AUDIO_PATH, str(global_step))
                 os.makedirs(file_path, exist_ok=True)
-                file_path = os.path.join(file_path,
-                                         "TestSentence_{}.wav".format(idx))
+                file_path = os.path.join(file_path, "TestSentence_{}.wav".format(idx))
                 ap.save_wav(wav, file_path)
-                test_audios['{}-audio'.format(idx)] = wav
-                test_figures['{}-prediction'.format(idx)] = plot_spectrogram(
-                    postnet_output, ap, output_fig=False)
-                test_figures['{}-alignment'.format(idx)] = plot_alignment(
-                    alignment, output_fig=False)
-            except:  #pylint: disable=bare-except
+                test_audios["{}-audio".format(idx)] = wav
+                test_figures["{}-prediction".format(idx)] = plot_spectrogram(postnet_output, ap, output_fig=False)
+                test_figures["{}-alignment".format(idx)] = plot_alignment(alignment, output_fig=False)
+            except:  # pylint: disable=bare-except
                 print(" !! Error creating Test Sentence -", idx)
                 traceback.print_exc()
-        tb_logger.tb_test_audios(global_step, test_audios,
-                                 c.audio['sample_rate'])
+        tb_logger.tb_test_audios(global_step, test_audios, c.audio["sample_rate"])
         tb_logger.tb_test_figures(global_step, test_figures)
     return keep_avg.avg_values
 
@@ -498,13 +589,12 @@ def main(args):  # pylint: disable=redefined-outer-name
     ap = AudioProcessor(**c.audio)
 
     # setup custom characters if set in config file.
-    if 'characters' in c.keys():
+    if "characters" in c.keys():
         symbols, phonemes = make_symbols(**c.characters)
 
     # DISTRUBUTED
     if num_gpus > 1:
-        init_distributed(args.rank, num_gpus, args.group_id,
-                         c.distributed["backend"], c.distributed["url"])
+        init_distributed(args.rank, num_gpus, args.group_id, c.distributed["backend"], c.distributed["url"])
     num_chars = len(phonemes) if c.use_phonemes else len(symbols)
     model_characters = phonemes if c.use_phonemes else symbols
 
@@ -512,10 +602,10 @@ def main(args):  # pylint: disable=redefined-outer-name
     meta_data_train, meta_data_eval = load_meta_data(c.datasets)
 
     # set the portion of the data used for training
-    if 'train_portion' in c.keys():
-        meta_data_train = meta_data_train[:int(len(meta_data_train) * c.train_portion)]
-    if 'eval_portion' in c.keys():
-        meta_data_eval = meta_data_eval[:int(len(meta_data_eval) * c.eval_portion)]
+    if "train_portion" in c.keys():
+        meta_data_train = meta_data_train[: int(len(meta_data_train) * c.train_portion)]
+    if "eval_portion" in c.keys():
+        meta_data_eval = meta_data_eval[: int(len(meta_data_eval) * c.eval_portion)]
 
     # parse speakers
     num_speakers, speaker_embedding_dim, speaker_mapping = parse_speakers(c, args, meta_data_train, OUT_PATH)
@@ -529,9 +619,7 @@ def main(args):  # pylint: disable=redefined-outer-name
     params = set_weight_decay(model, c.wd)
     optimizer = RAdam(params, lr=c.lr, weight_decay=0)
     if c.stopnet and c.separate_stopnet:
-        optimizer_st = RAdam(model.decoder.stopnet.parameters(),
-                             lr=c.lr,
-                             weight_decay=0)
+        optimizer_st = RAdam(model.decoder.stopnet.parameters(), lr=c.lr, weight_decay=0)
     else:
         optimizer_st = None
 
@@ -539,13 +627,13 @@ def main(args):  # pylint: disable=redefined-outer-name
     criterion = TacotronLoss(c, stopnet_pos_weight=c.stopnet_pos_weight, ga_sigma=0.4)
     if args.restore_path:
         print(f" > Restoring from {os.path.basename(args.restore_path)}...")
-        checkpoint = torch.load(args.restore_path, map_location='cpu')
+        checkpoint = torch.load(args.restore_path, map_location="cpu")
         try:
             print(" > Restoring Model...")
-            model.load_state_dict(checkpoint['model'])
+            model.load_state_dict(checkpoint["model"])
             # optimizer restore
             print(" > Restoring Optimizer...")
-            optimizer.load_state_dict(checkpoint['optimizer'])
+            optimizer.load_state_dict(checkpoint["optimizer"])
             if "scaler" in checkpoint and c.mixed_precision:
                 print(" > Restoring AMP Scaler...")
                 scaler.load_state_dict(checkpoint["scaler"])
@@ -554,17 +642,16 @@ def main(args):  # pylint: disable=redefined-outer-name
         except (KeyError, RuntimeError):
             print(" > Partial model initialization...")
             model_dict = model.state_dict()
-            model_dict = set_init_dict(model_dict, checkpoint['model'], c)
+            model_dict = set_init_dict(model_dict, checkpoint["model"], c)
             # torch.save(model_dict, os.path.join(OUT_PATH, 'state_dict.pt'))
             # print("State Dict saved for debug in: ", os.path.join(OUT_PATH, 'state_dict.pt'))
             model.load_state_dict(model_dict)
             del model_dict
 
         for group in optimizer.param_groups:
-            group['lr'] = c.lr
-        print(" > Model restored from step %d" % checkpoint['step'],
-              flush=True)
-        args.restore_step = checkpoint['step']
+            group["lr"] = c.lr
+        print(" > Model restored from step %d" % checkpoint["step"], flush=True)
+        args.restore_step = checkpoint["step"]
     else:
         args.restore_step = 0
 
@@ -577,9 +664,7 @@ def main(args):  # pylint: disable=redefined-outer-name
         model = apply_gradient_allreduce(model)
 
     if c.noam_schedule:
-        scheduler = NoamLR(optimizer,
-                           warmup_steps=c.warmup_steps,
-                           last_epoch=args.restore_step - 1)
+        scheduler = NoamLR(optimizer, warmup_steps=c.warmup_steps, last_epoch=args.restore_step - 1)
     else:
         scheduler = None
 
@@ -587,22 +672,17 @@ def main(args):  # pylint: disable=redefined-outer-name
     print("\n > Model has {} parameters".format(num_params), flush=True)
 
     if args.restore_step == 0 or not args.best_path:
-        best_loss = float('inf')
+        best_loss = float("inf")
         print(" > Starting with inf best loss.")
     else:
-        print(" > Restoring best loss from "
-              f"{os.path.basename(args.best_path)} ...")
-        best_loss = torch.load(args.best_path,
-                               map_location='cpu')['model_loss']
+        print(" > Restoring best loss from " f"{os.path.basename(args.best_path)} ...")
+        best_loss = torch.load(args.best_path, map_location="cpu")["model_loss"]
         print(f" > Starting with loaded last best loss {best_loss}.")
-    keep_all_best = c.get('keep_all_best', False)
-    keep_after = c.get('keep_after', 10000)  # void if keep_all_best False
+    keep_all_best = c.get("keep_all_best", False)
+    keep_after = c.get("keep_after", 10000)  # void if keep_all_best False
 
     # define data loaders
-    train_loader = setup_loader(ap,
-                                model.decoder.r,
-                                is_val=False,
-                                verbose=True)
+    train_loader = setup_loader(ap, model.decoder.r, is_val=False, verbose=True)
     eval_loader = setup_loader(ap, model.decoder.r, is_val=True)
 
     global_step = args.restore_step
@@ -617,28 +697,29 @@ def main(args):  # pylint: disable=redefined-outer-name
                 model.decoder_backward.set_r(r)
             train_loader.dataset.outputs_per_step = r
             eval_loader.dataset.outputs_per_step = r
-            train_loader = setup_loader(ap,
-                                        model.decoder.r,
-                                        is_val=False,
-                                        dataset=train_loader.dataset)
-            eval_loader = setup_loader(ap,
-                                       model.decoder.r,
-                                       is_val=True,
-                                       dataset=eval_loader.dataset)
+            train_loader = setup_loader(ap, model.decoder.r, is_val=False, dataset=train_loader.dataset)
+            eval_loader = setup_loader(ap, model.decoder.r, is_val=True, dataset=eval_loader.dataset)
             print("\n > Number of output frames:", model.decoder.r)
         # train one epoch
-        train_avg_loss_dict, global_step = train(train_loader, model,
-                                                 criterion, optimizer,
-                                                 optimizer_st, scheduler, ap,
-                                                 global_step, epoch, scaler,
-                                                 scaler_st)
+        train_avg_loss_dict, global_step = train(
+            train_loader,
+            model,
+            criterion,
+            optimizer,
+            optimizer_st,
+            scheduler,
+            ap,
+            global_step,
+            epoch,
+            scaler,
+            scaler_st,
+        )
         # eval one epoch
-        eval_avg_loss_dict = evaluate(eval_loader, model, criterion, ap,
-                                      global_step, epoch)
+        eval_avg_loss_dict = evaluate(eval_loader, model, criterion, ap, global_step, epoch)
         c_logger.print_epoch_end(epoch, eval_avg_loss_dict)
-        target_loss = train_avg_loss_dict['avg_postnet_loss']
+        target_loss = train_avg_loss_dict["avg_postnet_loss"]
         if c.run_eval:
-            target_loss = eval_avg_loss_dict['avg_postnet_loss']
+            target_loss = eval_avg_loss_dict["avg_postnet_loss"]
         best_loss = save_best_model(
             target_loss,
             best_loss,
@@ -651,14 +732,13 @@ def main(args):  # pylint: disable=redefined-outer-name
             model_characters,
             keep_all_best=keep_all_best,
             keep_after=keep_after,
-            scaler=scaler.state_dict() if c.mixed_precision else None
+            scaler=scaler.state_dict() if c.mixed_precision else None,
         )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     args = parse_arguments(sys.argv)
-    c, OUT_PATH, AUDIO_PATH, c_logger, tb_logger = process_args(
-        args, model_type='tacotron')
+    c, OUT_PATH, AUDIO_PATH, c_logger, tb_logger = process_args(args, model_class="tts")
 
     try:
         main(args)
